@@ -1,5 +1,6 @@
 import datetime
 import enum
+import re
 
 
 class FilePeriod(enum.Enum):
@@ -75,6 +76,32 @@ class FilePeriod(enum.Enum):
 
 # ------------------------------------------------------------------------------
 
+def strftime(epoch, fmt):
+    """
+
+    >>> epoch = datetime.datetime(2019, 8, 3, 10, 10, 10)
+    >>> strftime(epoch, "ebre215${rinexhour}${rinexquarter}.19o")
+    'ebre215j00.19o'
+
+    >>> epoch = datetime.datetime(2019, 8, 3, 10, 50, 10)
+    >>> strftime(epoch, "ebre215${RINEXHOUR}${rinexQUARTER}.19o")
+    'ebre215j45.19o'
+    """
+
+    RINEX_HOUR = "abcdefghijklmnopqrstuvwxyz"
+
+    PATTERN_HOUR = re.compile(r"\$\{rinexhour\}", re.IGNORECASE)
+    PATTERN_QUARTER = re.compile(r"\$\{rinexquarter\}", re.IGNORECASE)
+
+    hour = RINEX_HOUR[epoch.hour - 1]
+    quarter = get_quarter_str(epoch.minute * 60 + epoch.second)
+
+    fmt = PATTERN_HOUR.sub(f"{hour}", fmt)
+    fmt = PATTERN_QUARTER.sub(f"{quarter:02d}", fmt)
+
+    return fmt
+
+
 def get_quarter_str(seconds):
     """
     Get the Rinex quarter string ("00", "15", "30", "45") for a given number of seconds
@@ -101,3 +128,4 @@ def get_quarter_str(seconds):
         return 30
     else:
         return 45
+
